import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.Scanner;

/**
 * This class contains a main method that creates a PoolProcessor object
 * to read a particular data file, prompts the user for the names of the
 * pools that tested positive, then has the PoolProcessor analyze the 
 * pools to see which subjects must be positive.
 *
 * @author David Chiu & Brad Richards
 * @version 1.0
 */
public class PooledSampleTester
{
    // Uncomment one of these to pick a sample file to use:
    // private static String FILE = "pooling384_48_by_pool.txt";
    private static String FILE = "pooling_example.txt";
    
    public static void main(String[] args) throws FileNotFoundException {

        // For the big pool, try these groups individually, or in combination:
        // A, I, Q, Y, AG, AO   Sample 1 is in all of these pools
        // B, J, R, Z, AH, AP   Sample 2 is in all of these pools
        // H N Q AA AL AV C P V Y AI AV     These contain 99 and 384
        
        System.out.println("Processing " + FILE + "...");
        PoolProcessor pp = new PoolProcessor(FILE);  

        // Get names of positive pools from the user.
        ArrayList<String> positiveLabels = inputPositivePoolIDs();

        // run the detection algorithm
        pp.detect(positiveLabels);
    }

    /**
     * Helper method to get a list of positive pool labels. Prompts the
     * user to enter names of positive pools, and adds them to a list.
     * 
     * @return The list of pool names entered by the user.
     */
    private static ArrayList<String> inputPositivePoolIDs() {
        String prompt = "Enter the ID of a pool testing positive (or \"stop\"): ";
        ArrayList<String> list = new ArrayList<>();
        Scanner keyboard = new Scanner(System.in);
        System.out.print(prompt);
        String in = keyboard.nextLine();
        while (!in.equalsIgnoreCase("stop")) {
            list.add(in);
            System.out.print(prompt);
            in = keyboard.nextLine();
        }
        return list;
    }
}